Rihards Balass / 4DGL-mbed-32PTU
Revision:
11:3ebd2263f3e9
Parent:
10:b959bb206e6b
Child:
12:29f5ad896382
--- a/Picaso_4DGL-32PTU.h	Tue Sep 13 05:53:39 2016 +0000
+++ b/Picaso_4DGL-32PTU.h	Tue Sep 13 11:37:04 2016 +0000
@@ -74,9 +74,19 @@
 #define ELIPSE_FILLED       0xFFB1
 #define DRAW_BUTTON         0x0011
 #define BEVEL_SHADOW        0xFF98
+#define BEVEL_WIDTH         0xFF99
 #define DRAW_PANEL          0xFFAF
 #define DRAW_SLIDER         0xFFAE
 #define SCREEN_CP           0xFFAD
+#define BG_COLOR            0xFFA4
+#define OUTLINE_COLOR       0xFF9D
+#define CONTRAST            0xFF9C
+#define FRAME_DELAY         0xFF9F
+#define LINE_PATERN         0xFF9B
+#define TRANSPARENCY        0xFFA0
+#define TRANSPARENT_COLOR   0xFFA1
+#define SET_GRAPHICS        0xFFCE
+#define GET_GRAPHICS        0xFFA6
 
 
 
@@ -177,6 +187,23 @@
 #define INDENTED    0
 #define RAISED      1
 #define HIDDEN      2
+// set graphic parameters
+#define objColor        18
+#define scrResolution   32
+#define pageDisplay     33
+#define pageRead        34
+#define pageWrite       35
+// get graphic parameters
+#define currentXMax     0
+#define currentYMax     1
+#define lastObjLeft     2
+#define lastObjTop      3
+#define lastObjRight    4
+#define lastObjBot      5
+// Screen resolution
+#define res320x240      0
+#define res640x480      1
+#define res800x480      2
 
 //**************************************************************************
 class PICASO_4DGL {
@@ -194,9 +221,9 @@
     void rxCallback();
     void getResponse(int); // wait for LCD response
     void calculateOrbitResponse(); // wait for LCD response
+    short getGraphicsResponse(); // wait for LCD response
     void reset(); // reset screen
     void baudrate(long); // set baudrate
-    void screenOrientation(char); // set desired orientation of a screen
     void mainDemo(); // play demo with text based functions
     void textDemo(); // play demo with text based functions
     void graphicsDemo(); // play demo with text based functions
@@ -224,10 +251,21 @@
     void clipping(short); // enable / disable clipping
     void extendClipRegion(); // extend clipping region to the last text or image shown
     void drawButton(short, short, short, short, short, short, short, short, char *); // draw a 3D button (state, x, y, btnColor, txtColor, font, txtWidth, txtHeight, string)
-    void bevelShadow(short); // change the drawButton bevel shadow depth
+    bool bevelShadow(short); // change the drawButton bevel shadow depth
+    bool bevelWidth(short); // change the drawButton bevel width
     void drawPanel(short, short, short, short, short, short); // draw a 3D panel (state, x, y, width, height, color)
     void drawSlider(short, short, short, short, short, short, short, short); // draw a slider bar (mode, x1, y1, x2, y2, color, scale, value)
     void screenCopyPaste(short, short, short, short, short, short); // copy a portion of screen (xs, ys, xd, yd, width, height)
+    void bgColor(short); // change background color
+    void outlineColor(short); // change outline color
+    void contrast(short); // change display contrast
+    bool frameDelay(short); // set inter frame delay for media video command
+    void linePatern(short); // set the line draw pattern for line drawing
+    void screenMode(char); // set desired orientation of a screen
+    void transparency(short); // turn on or off transparency
+    void transparentColor(short); // change transparent to color
+    void setGraphics(short, short); // set graphics parameters
+    short getGraphics(short); // get graphics parameters
     
 // Texts Commands
     void setFont(char); // set desired font from embedded fonts